Fedimg is packaged for EPEL 7. The latest version been tested on RHEL 7.

Install Fedimg with yum:

```
yum install python-fedimg
```

The configration file should be found at `/etc/fedimg.cfg`. You will have to
modify this file before Fedimg will work. Read [the configuration
docs](configuration.md) for more info.
